{% extends "base.html" %}

{% block title %}Components in {{suite}}/{{section}}{% endblock %}

{% block header_content %}
<span style="font-size:18px;"><a href="../" style="color: #000000;">⇦ |</a></span>
<span>Components summary for {{suite}}/{{section}}</span>
{% endblock %}

{% block float_right %}
<small>Last updated on: {{time}}</small>
{% endblock %}

{% block content %}
<h1>Metadata for {{suite}}/{{section}}</h1>

{% for summary in summaries %}
  <h3 id="{{summary.maintainer_anchor}}">{{summary.maintainer}} <a title="Permalink" class="permalink" href="#{{summary.maintainer_anchor}}">#</a></h3>
  <ul class="overviewlisting">
  {% for package in summary.packages %}
    <li>
      <span style="font-size:16px;">
      <a href="{{package.pkgname}}.html">{{package.pkgname}}</a>&nbsp;
      </span>

      <ul>
      {% for component in package.components %}
        <li>{{component.cid}}</li>
      {% endfor %}
      </ul>

    </li>
  {% endfor %}
  </ul>
{% endfor %}
{% endblock %}
