{% extends "base.html" %}

{% block title %}Issues for {{package_name}} in {{suite}}/{{section}}{% endblock %}

{% block float_right %}
<small>Last updated on: {{time}}</small>
{% endblock %}

{% block header_content %}
<span style="font-size:18px;"><a href="index.html" style="color: #000000;">⇦ |</a></span>
<span>{{package_name}}</span> <span style="font-size:16px;">[{{section}}]</span>
{% endblock %}

{% block content %}
<h1>Hints for {{package_name}} in {{section}}</h1>

<div class="wrapper">

{% for entry in entries %}
<h2>
  {{entry.component_id}}
  {% for arch in entry.architectures %}
    <span style="font-size:12px;" class="label label-neutral">⚙ {{arch.arch}}</span>
  {% endfor %}
</h2>

  {% if entry.has_errors %}
  <div class="infobox infobox-error">
    <h2>Errors</h2>
    <ul class="list-group">
      {% for error in entry.errors %}
        <li class="list-group-item list-group-item-info">
        <strong>{{error.error_tag}}</strong><br/>
        {{error.error_description}}
        </li>
      {% endfor %}
    </ul>
  </div>
  {% endif %}

  {% if entry.has_warnings %}
  <div class="infobox infobox-warning">
    <h2>Warnings</h2>
    <ul class="list-group">
      {% for warning in entry.warnings %}
        <li class="list-group-item list-group-item-info">
        <strong>{{warning.warning_tag}}</strong><br/>
        {{warning.warning_description}}
        </li>
      {% endfor %}
    </ul>
  </div>
  {% endif %}

  {% if entry.has_infos %}
  <div class="infobox infobox-hint">
    <h2>Hints</h2>
    <ul class="list-group">
      {% for info in entry.infos %}
        <li class="list-group-item list-group-item-info">
        <strong>{{info.info_tag}}</strong><br/>
        {{info.info_description}}
        </li>
      {% endfor %}
    </ul>
  </div>
  {% endif %}

{% endfor %}

</div>
{% endblock %}
