html {
    font-size: 100%;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust:100%;
    height:100%;
}

body {
    border-sizing: border-box;
    font-family: Cantarell,"Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 14px;
    line-height: 20px;
    color: #333333;
    margin: 0;
    height: 93%;
}

a {
    color: #337ab7;
    text-decoration: none;
    background-color: transparent;
}

.headbar {
    border-radius: 4px;
    display: block;
    border: 1px solid transparent;
    margin-bottom: 20px;
    min-height: 50px;
    position: relative;

    background-color: #f8f8f8;
    border-color: #e7e7e7;
    border-width: 0 0 1px;
    z-index: 1000;
    border-radius: 0;
    margin-bottom: 14px;
}

.headbar-content {
    font-size: 18px;
    line-height: 20px;
    padding: 15px;
    float: left;
}

.headbar-content-right {
    font-size: 14px;
    line-height: 20px;
    padding: 15px;
    float: right;
}

.content {
    padding: 0em 1em 0em 1em;
}

.wrapper {
    width: 60%;
}

.wrapper hr {
    border-top: none;
    border-bottom: 1px solid #819eb7;
    margin-bottom: 1em;
}

img.fit {
    max-width: 99%;
    max-height: 99%;
}

hr {
    border-top: none;
    border-bottom: 1px solid #0a630d;
    margin-bottom: 1em;
}

footer {
    text-align: center;
    margin-top: 1em;
}

span.avoidwrap { display: inline-block; }

.infobox {
    border-color: #eee;
    border-image: none;
    border-radius: 3px;
    border-style: solid;
    border-width: 1px 1px 1px 5px;
    margin: 20px 0;
    padding: 20px;
}

.infobox h2 {
    margin-bottom: 5px;
    margin-top: 0;
}

.infobox p:last-child {
    margin-bottom: 0
}

.infobox-hint {
    border-left-color: #1b809e;
}

.infobox-hint h2 {
    color: #1b809e;
}

.infobox-error {
    border-left-color: #ce4844;
}

.infobox-error h2 {
    color: #ce4844;
}

.infobox-warning {
    border-left-color: #aa6708;
}

.infobox-warning h2 {
    color: #aa6708;
}

/* label styles copied from Bootstrap */
.label {
    border-radius: 0.25em;
    color: #fff;
    display: inline;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    padding: 0.2em 0.6em 0.3em;
    text-align: center;
    vertical-align: baseline;
    white-space: nowrap;
}

.label-info {
    background-color: #5bc0de;
}

.label-warning {
    background-color: #f0ad4e;
}

.label-error {
    background-color: #d9534f;
}

.label-neutral {
    background-color: #777;
}

.overviewlisting a {
    color: #000000;
    text-decoration: none;
}

.overviewlisting li {
   padding: 2px 4px 2px;
}

code {
    background-color: #f9f2f4;
    border-radius: 4px;
    color: #c7254e;
    font-size: 90%;
    padding: 2px 4px;
}

.well{
    min-height:20px;
    padding:19px;
    margin-bottom:20px;
    background-color:#f5f5f5;
    border:1px solid #e3e3e3;
    border-radius:4px;
    -webkit-box-shadow:
    inset 0 1px 1px rgba(0,0,0,.05);
    box-shadow:inset 0 1px 1px rgba(0,0,0,.05)
}

.progress {
    background-color: #f5f5f5;
    border-radius: 4px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset;
    height: 20px;
    margin-bottom: 20px;
    overflow: hidden;
}

.progress-bar {
    background-color: #337ab7;
    box-shadow: 0 -1px 0 rgba(0, 0, 0, 0.15) inset;
    color: #fff;
    float: left;
    font-size: 12px;
    height: 100%;
    line-height: 20px;
    text-align: center;
    transition: width 0.6s ease 0s;
    width: 0;
}

.progress-bar-blue {
    background-color: #5bc0de;
}

.progress-bar-green {
    background-color: #5cb85c;
}

.progress-bar-yellow {
    background-color: #f0ad4e;
}

.progress-bar-red {
    background-color: #d9534f;
}

.sr-only {
    border: 0 none;
    clip: rect(0px, 0px, 0px, 0px);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute;
    width: 1px;
}

.permalink {
    font-size: 75%;
    color: #999;
    line-height: 100%;
    font-weight: normal;
    text-decoration: none;
}
