{% extends "base.html" %}

{% block title %}Start{% endblock %}

{% block header_content %}
AppStream data hints for {{project_name}}
{% endblock %}

{% block content %}
<div class="wrapper">

    <h1>Welcome!</h1>
    <p>Welcome to the AppStream Generator HTML pages!</p>
    <p>
      These pages exist to provide a user-friendly view on the issues discovered by the
      AppStream metadata generator while extracting metadata from packages in the {{project_name}} archive.
      They can also be used to take a look at the raw metadata, to spot possible problems
      with the data itself or the generation process.
    </p>

    <h1>Select a suite</h1>
    {% for suite in suites %}
      <h3><a href="{{suite.suite}}/index.html">{{suite.suite}}</a></h3>
    {% endfor %}
    <br/>
    {% for oldsuite in oldsuites %}
      <h3><a href="{{oldsuite.suite}}/index.html">{{oldsuite.suite}}</a></h3>
    {% endfor %}

    <br/><hr/>
    <img src="{{root_url}}/static/img/asgen.png" alt="AppStream Generator Logo" style="margin: 4px; float: right;" />

    <h1>What is AppStream and DEP-11?</h1>
    <p>
      AppStream is a cross-distro XML format to provide metadata for software components and to assign unique identifiers to software.<br/>
      In Debian, we parse all XML provided by upstream projects as well as other metadata (.desktop-files, ...), and compile a single YAML
      metadata file from it, which is then shipped to users via APT.
    </p>
    <p>
      While the official AppStream specification is based on XML, Debian uses a YAML version of the format for easier use in existing
      scripts and for better archive integration. This format is called DEP-11, and initially had a much wider scope in enhancing
      archive metadata than AppStream had. Today AppStream covers that as well, and DEP-11 is only a YAML version of AppStream.
    </p>
    <p>
      The generated metadata can for example be used by software centers like GNOME Software or KDE Discover to display a user-friendly application-centric
      view on the package archive.<br/>
      It can also be used by other software to find missing plugins, codecs, fonts, etc. or simply by users to install software on any Linux distribution
      without knowing the exact package name.
    </p>

    <h1>More information</h1>
    <p>
      See <a href="https://wiki.debian.org/AppStream">AppStream @ wiki.d.o</a> for information about AppStream integration and usage in Debian.<br/>
      The offical AppStream specification can be found at <a href="http://www.freedesktop.org/software/appstream/docs/">freedesktop.org</a>, a description
      of the <a href="https://www.freedesktop.org/software/appstream/docs/sect-AppStream-YAML.html">DEP-11 YAML format</a> is hosted there as well.
    </p>
    <p>
      You can find the source-code of the AppStream Generator <a href="https://github.com/ximion/appstream-generator">here</a>.
    </p>
    <p>
      Log files of the generator runs are stored in <a href="logs/">logs/</a>, machine-readable issue hints can be found in <a href="hints/">hints/</a>,
      valid metadata is located in <a href="data/">data/</a> and all exported media is made available via <a href="media/">media/</a>.
    </p>

</div>
{% endblock %}
